baseStore.SrbBdbCombineStore

|  | ## Cheshire3 Object Model: Class SrbBdbCombineStore

Module baseStore :: Class SrbBdbCombineStore

## Class SrbBdbCombineStore
source code

Object Tree:

                   object --+
                            |
        configParser.C3Object --+
                                |
                         SrbStore --+
                                    |
               object --+           |
                        |           |
    configParser.C3Object --+       |
                            |       |
                  SimpleStore --+   |
                                |   |
                         BdbStore --+
                                    |
                                   SrbBdbCombineStore

Known Subclasses:
  documentStore.CachingSrbDocumentStore, recordStore.CachingSrbRecordStore, recordStore.CachingSrbRemoteWriteRecordStore

Combined BerkeleyDB in SRB based Storage
Instance Methods

__init__(self, session, config, parent)
_verifyDatabases(self, session)
begin_storing(self, session)
commit_storing(self, session)
generate_id(self, session)
verify_checkSum(self, session, id, data, store=1)
fetch_checkSum(self, session, id)
fetch_size(self, session, id)
store_checkSum(self, session, id, digest)
delete_item(self, session, id)
fetch_idList(self, session, numReq=-1, start="")
clean(self, session)
fetch_data(self, session, id)
store_data(self, session, id, data, size=0)
_writeCache(self, session)
_writeSingle(self, session, info)
Inherited from `SrbStore` (private): `_closeContainer`, `_openContainer` Inherited from `BdbStore`: `__iter__`, `fetch_checksum`, `get_dbsize` Inherited from `BdbStore` (private): `_initialise`, `_verifyDatabase` Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

maxRecords |
incomingRecords |
cachedFilename |
cachedTarfile |
Inherited from `SrbStore`: `checkSumHash`, `connection`, `currentId`, `dn`, `domain`, `host`, `passwd`, `port`, `resource`, `subcollection`, `user` Inherited from `BdbStore`: `cxn`, `digestCxn`, `digestForId` Inherited from `SimpleStore`: `idNormalizer` Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### __init__(self, session, config, parent) (Constructor) | source code
Overrides: SrbStore.__init__

### _verifyDatabases(self, session) | source code
Overrides: BdbStore._verifyDatabases

### begin_storing(self, session) | source code
Overrides: SrbStore.begin_storing

### commit_storing(self, session) | source code
Overrides: SrbStore.commit_storing

### generate_id(self, session) | source code
Overrides: SrbStore.generate_id

### verify_checkSum(self, session, id, data, store=1) | source code
Overrides: SrbStore.verify_checkSum

### fetch_checkSum(self, session, id) | source code
Overrides: SrbStore.fetch_checkSum

### fetch_size(self, session, id) | source code
Overrides: SrbStore.fetch_size

### store_checkSum(self, session, id, digest) | source code
Overrides: SrbStore.store_checkSum

### delete_item(self, session, id) | source code
Overrides: SrbStore.delete_item

### fetch_idList(self, session, numReq=-1, start="") | source code
Overrides: SrbStore.fetch_idList

### clean(self, session) | source code
Overrides: SrbStore.clean

### fetch_data(self, session, id) | source code
Overrides: SrbStore.fetch_data

### store_data(self, session, id, data, size=0) | source code
Overrides: SrbStore.store_data

### _writeCache(self, session) | source code

### _writeSingle(self, session, info) | source code

Class Variable Details

    ### maxRecords Value:
        100

    ### incomingRecords Value:
        []

    ### cachedFilename Value:
        ""

    ### cachedTarfile Value:
        ""